API Reference
=============

.. automodule:: tf_fits.image
     :members: image_decode_fits

|

.. automodule:: tf_fits.bintable
     :members: bintable_decode_fits

|

.. automodule:: tf_fits.asciitable
    :members: asciitable_decode_fits
